Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/displayio_layout_simpletest.py
    :caption: examples/displayio_layout_simpletest.py
    :linenos:

Switch simple test
------------------

Create a single sliding switch.

.. literalinclude:: ../examples/displayio_layout_switch_simpletest.py
    :caption: examples/displayio_layout_switch_simpletest.py
    :linenos:

Switch test with multiple switches
----------------------------------

Create multiple sliding switch with various sizes and orientations.

.. literalinclude:: ../examples/displayio_layout_switch_multiple.py
    :caption: examples/displayio_layout_switch_multiple.py
    :linenos:
